@@ -4,8 +4,35 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <source>CSSU Transitions tuner</source>
-        <translation>CSSU Transitions Tuner</translation>
+        <source>CSSU Tuner</source>
+        <translation>CSSU Tuner</translation>
+    </message>
+    <message>
+        <source>Transitions lenght (ms)</source>
+        <translation>Animaation kesto (ms)</translation>
+    </message>
+    <message>
+        <source>Status menu rows</source>
+        <translation>Tilavalikon näkyvät
+rivit</translation>
+    </message>
+    <message>
+        <source>Status menu rows
+(portait)</source>
+        <translation>Tilavalikon näkyvät
+rivit (pystymoodi)</translation>
+    </message>
+    <message>
+        <source>Always show FM-applet</source>
+        <translation>Näytä aina FM-appletti</translation>
+    </message>
+    <message>
+        <source>App menu editing Enabled</source>
+        <translation>Ohj. valikko muokattavissa</translation>
+    </message>
+    <message>
+        <source>Homescreen editing Enabled</source>
+        <translation>Työpöytä muokattavissa</translation>
     </message>
     <message>
         <source>Ultra fast Transitions</source>
