@@ -9,28 +9,28 @@
     </message>
     <message>
         <source>Transitions lenght (ms)</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergangslänge (ms)</translation>
     </message>
     <message>
         <source>Status menu rows</source>
-        <translation type="unfinished"></translation>
+        <translation>Reihen im Statusmenü</translation>
     </message>
     <message>
         <source>Status menu rows
 (portait)</source>
-        <translation type="unfinished"></translation>
+        <translation>Reihen im Statusmenü &lt;br /&gt; (Hochformat)</translation>
     </message>
     <message>
         <source>Always show FM-applet</source>
-        <translation type="unfinished"></translation>
+        <translation>UKW Transmitter immer anzeigen</translation>
     </message>
     <message>
         <source>App menu editing Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Programmmenü editierbar</translation>
     </message>
     <message>
         <source>Homescreen editing Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Homescreen editierbar</translation>
     </message>
     <message>
         <source>Ultra fast Transitions</source>
@@ -70,7 +70,7 @@
     </message>
     <message>
         <source>App menu scroll speed</source>
-        <translation type="unfinished"></translation>
+        <translation>Programmmenü&lt;br /&gt; Scrollgeschwindigkeit</translation>
     </message>
     <message>
         <source>Parallax</source>
@@ -94,7 +94,7 @@
     </message>
     <message>
         <source>Zoom on press Enabled</source>
-        <translation type="unfinished">Zoom beim Berühren</translation>
+        <translation>Zoom beim Berühren</translation>
     </message>
     <message>
         <source>About</source>
